@@ -3,7 +3,7 @@ from __future__ import absolute_import, unicode_literals
 import logging
 import sys
 
-import six
+from virtualenv.util.six import ensure_str
 
 LEVELS = {
     0: logging.CRITICAL,
@@ -18,8 +18,7 @@ MAX_LEVEL = max(LEVELS.keys())
 LOGGER = logging.getLogger()
 
 
-def setup_report(verbose, quiet):
-    verbosity = max(verbose - quiet, 0)
+def setup_report(verbosity):
     _clean_handlers(LOGGER)
     if verbosity > MAX_LEVEL:
         verbosity = MAX_LEVEL  # pragma: no cover
@@ -33,7 +32,7 @@ def setup_report(verbose, quiet):
     else:
         filelock_logger.setLevel(logging.WARN)
 
-    formatter = logging.Formatter(six.ensure_str(msg_format))
+    formatter = logging.Formatter(ensure_str(msg_format))
     stream_handler = logging.StreamHandler(stream=sys.stdout)
     stream_handler.setLevel(level)
     LOGGER.setLevel(logging.NOTSET)
@@ -41,6 +40,7 @@ def setup_report(verbose, quiet):
     LOGGER.addHandler(stream_handler)
     level_name = logging.getLevelName(level)
     logging.debug("setup logging to %s", level_name)
+    logging.getLogger("distlib").setLevel(logging.ERROR)
     return verbosity
 
 
