@@ -82,7 +82,7 @@ def test_satisfy_py_info(spec):
 
 def test_satisfy_not_arch():
     parsed_spec = PythonSpec.from_string_spec(
-        "{}-{}".format(CURRENT.implementation, 64 if CURRENT.architecture == 32 else 32)
+        "{}-{}".format(CURRENT.implementation, 64 if CURRENT.architecture == 32 else 32),
     )
     matches = CURRENT.satisfies(parsed_spec, True)
     assert matches is False
@@ -261,9 +261,9 @@ def test_py_info_ignores_distutils_config(monkeypatch, tmp_path):
             install_scripts={0}{1}scripts
             install_data={0}{1}data
             """.format(
-                tmp_path, os.sep
-            )
-        )
+                tmp_path, os.sep,
+            ),
+        ),
     )
     monkeypatch.chdir(tmp_path)
     py_info = PythonInfo.from_exe(sys.executable)
@@ -287,7 +287,7 @@ def test_discover_exe_on_path_non_spec_name_not_match(mocker):
         suffixed_name += Path(CURRENT.original_executable).suffix
     spec = PythonSpec.from_string_spec(suffixed_name)
     mocker.patch.object(
-        CURRENT, "original_executable", str(Path(CURRENT.executable).parent / "e{}".format(suffixed_name))
+        CURRENT, "original_executable", str(Path(CURRENT.executable).parent / "e{}".format(suffixed_name)),
     )
     assert CURRENT.satisfies(spec, impl_must_match=True) is False
 
